#
# spec file for package python-Parsley
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define modname  Parsley
%define oldpython python
Name:           python-Parsley
Version:        1.3
Release:        6.6
Summary:        PEG algorithm based parser generator
License:        MIT
URL:            https://github.com/pyga/parsley
Source:         https://files.pythonhosted.org/packages/source/P/%{modname}/%{modname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#pyga/parsley#82
Patch0:         support-python312.patch
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-parsley
Obsoletes:      %{oldpython}-Parsley-doc
Obsoletes:      python-Parsley-doc
BuildArch:      noarch
%python_subpackages

%description
Parsley is a parsing library. Most parser generators like ANTLR and
Bison are based on LL or LR parsing algorithms that compile to big
state machine tables, whereas Parsley, like pyparsing and
ZestyParser, uses the PEG algorithm, so each expression in the
grammar rules works like a Python expression. In particular,
alternatives are evaluated in order, unlike table-driven parsers such
as yacc, bison or PLY.

The binaries are prefixed with parsley-.

%prep
%autosetup -p1 -n %{modname}-%{version}
# Remove with bump, missing fixtures
rm -f ometa/test/test_vm_builder.py

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
mkdir %{buildroot}/%{_bindir}
# rename binaries in order to avoid name clashes with other system packages
for f in {generate_parser,stage}; do
    sed -i \
	-e "s|^#!%{_bindir}/env python$|#!%{_bindir}/python3|" \
	bin/$f
    cp -v bin/$f %{buildroot}/%{_bindir}/parsley-$f
    %python_clone -a %{buildroot}%{_bindir}/parsley-$f
done

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest ometa/test
%pytest terml/test

%post
%python_install_alternative parsley-stage
%python_install_alternative parsley-generate_parser

%postun
%python_uninstall_alternative parsley-stage
%python_uninstall_alternative parsley-generate_parser

%files %{python_files}
%license LICENSE
%doc NEWS PKG-INFO README
%python_alternative %{_bindir}/parsley-stage
%python_alternative %{_bindir}/parsley-generate_parser
%{python_sitelib}/parsley.py
%pycache_only %{python_sitelib}/__pycache__/parsley.*.py*
%{python_sitelib}/terml
%{python_sitelib}/ometa
%{python_sitelib}/Parsley-%{version}.dist-info

%changelog
* Tue Jan  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python312.patch:
  * Support Python 3.12 by using non-removed assertion functions.
- Switch to autosetup and pyproject macros.
- Correct URL.
- Stop using greedy globs in %%files.
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Wed Aug 12 2020 Matej Cepl <mcepl@suse.com>
- Replace pypi.python.org Source URL with the canonical files.pythonhosted.org
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Sat Aug 25 2018 jengelh@inai.de
- Use noun phrase in summary. Strip storytelling from description.
* Thu Aug 23 2018 tchvatal@suse.com
- Version update to 1.3:
  * support py3
  * tests redone in pytest
- Run all tests
- Switch to singlespec
- Do not generate the docu and obsolete the doc subpkg
* Sun Jun  7 2015 nemysis@gmx.ch
- Use %%{oname} instead of Parsley
- Use check for openSUSE %%if 0%%{?suse_version}
- Correct what fdupes not have found (docs)
- Use right files name instead of %%{_bindir}/* and %%{python_sitelib}/*
* Tue Sep 24 2013 hpj@urpla.net
- version 1.2
  - Added 'makeProtocol' for parsing stream protocols using Parsley
  grammars and Twisted, with examples, docs, and a tutorial.
  - Added 'stack' as support for 'makeProtocol'.
  - Sped up parsing; started compiling python expressons only once.
  (thanks to eevee!)
  - Allowed tuple unpacking in assignment in rules. For example,
  `rule1 = rule2:(a, b) -> a + b`. (thanks to introom!)
  - Added a trace hook and an example of a trace visualizer using it.
  - Fixed an example in the README. (thanks to ilmarga!)
  - Added support for custom labels in grammars. For example,
  `rule1 = rule2 ^(foo)` will make Parsley consider 'foo' the name for
  'rule2' in error messages. (thanks to miebster!)
* Thu Aug  1 2013 hpj@urpla.net
- spec file clean up and prefix binaries with parsley-
* Fri Mar 29 2013 hpj@urpla.net
- python-Parsley version 1.1 (initial package)
